Module buffer

Module buffer 

Persistent buffer for crash recovery

The persistent buffer acts as a safety net to prevent memory loss even if all hooks fail. It continuously buffers session context for recovery after crashes.

Structs

BufferData
Buffer data structure stored on disk
BufferEntry
Buffer entry stored in memory and on disk
BufferStatus
Buffer status information
PersistentBuffer
Persistent buffer for crash recovery

Functions

default_buffer_dir
Default buffer directory